django-relatives
================

django-relatives provides various utilites that make it easy to link related
objects in the Django admin site.

Contents:

.. toctree::
   :maxdepth: 2

   usage
   api

Visit the project `on Github`_ to view the source, submit issues and pull
requests.

.. _on github: https://github.com/treyhunner/django-relatives

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

